commit.c: add repo_get_commit_tree()
authorNguyễn Thái Ngọc Duy <pclouds@gmail.com>
Tue, 16 Apr 2019 09:33:19 +0000 (16:33 +0700)
committerJunio C Hamano <gitster@pobox.com>
Tue, 16 Apr 2019 09:56:51 +0000 (18:56 +0900)
Remove the implicit dependency on the_repository in this function.
It will be used in sha1-name.c functions when they are updated to take
any 'struct repository'. get_commit_tree() remains as a compat wrapper,
to be slowly replaced later.

Any access to "maybe_tree" field directly will result in _broken_ code
after running through commit.cocci because we can't know what is the
right repository to use.

the_repository would be correct most of the time. But we're relying less
and less on the_repository and that assumption may no longer be
true. The transformation now is more of a poor man replacement for a C++
compiler catching access to private fields.

Signed-off-by: Nguyễn Thái Ngọc Duy <pclouds@gmail.com>
Signed-off-by: Junio C Hamano <gitster@pobox.com>
commit.c
commit.h
contrib/coccinelle/commit.cocci
index 043ba64f1755492e4aaafaf8da38b7edd8c8556a..a9e74647dc822606d06f79bcf94030b32998bd69 100644 (file)
--- a/commit.c
+++ b/commit.c
@@ -345,7 +345,8 @@ static inline void set_commit_tree(struct commit *c, struct tree *t)
        c->maybe_tree = t;
 }
 
-struct tree *get_commit_tree(const struct commit *commit)
+struct tree *repo_get_commit_tree(struct repository *r,
+                                 const struct commit *commit)
 {
        if (commit->maybe_tree || !commit->object.parsed)
                return commit->maybe_tree;
@@ -353,7 +354,7 @@ struct tree *get_commit_tree(const struct commit *commit)
        if (commit->graph_pos == COMMIT_NOT_FROM_GRAPH)
                BUG("commit has NULL tree, but was not loaded from commit-graph");
 
-       return get_commit_tree_in_graph(the_repository, commit);
+       return get_commit_tree_in_graph(r, commit);
 }
 
 struct object_id *get_commit_tree_oid(const struct commit *commit)
index 42728c2906608a9f4f1724e02b16d913b74b8728..f1aa4c04727223c0b24e3e01b90f2a3f11b9c64e 100644 (file)
--- a/commit.h
+++ b/commit.h
@@ -32,7 +32,7 @@ struct commit {
 
        /*
         * If the commit is loaded from the commit-graph file, then this
* member may be NULL. Only access it through get_commit_tree()
         * or get_commit_tree_oid().
         */
        struct tree *maybe_tree;
@@ -143,7 +143,8 @@ void repo_unuse_commit_buffer(struct repository *r,
  */
 void free_commit_buffer(struct parsed_object_pool *pool, struct commit *);
 
-struct tree *get_commit_tree(const struct commit *);
+struct tree *repo_get_commit_tree(struct repository *, const struct commit *);
+#define get_commit_tree(c) repo_get_commit_tree(the_repository, c)
 struct object_id *get_commit_tree_oid(const struct commit *);
 
 /*
index 663658a127e653e69bcf3d4576831272890c834f..d03453341e84c912e14d8b421b47857e7eb244b1 100644 (file)
@@ -23,12 +23,12 @@ expression s;
 // These excluded functions must access c->maybe_tree direcly.
 // Note that if c->maybe_tree is written somewhere outside of these
 // functions, then the recommended transformation will be bogus with
// get_commit_tree() on the LHS.
 @@
-identifier f !~ "^(get_commit_tree|get_commit_tree_in_graph_one|load_tree_for_commit|set_commit_tree)$";
+identifier f !~ "^(repo_get_commit_tree|get_commit_tree_in_graph_one|load_tree_for_commit|set_commit_tree)$";
 expression c;
 @@
   f(...) {<...
 - c->maybe_tree
-+ get_commit_tree(c)
++ repo_get_commit_tree(specify_the_right_repo_here, c)
   ...>}
@@ -32,7 +32,7 @@ struct commit {
        /*
         * If the commit is loaded from the commit-graph file, then this
-        * member may be NULL. Only access it through get_commit_tree()
+        * member may be NULL. Only access it through repo_get_commit_tree()
         * or get_commit_tree_oid().
         */
@@ -23,12 +23,12 @@ expression s;
 // Note that if c->maybe_tree is written somewhere outside of these
 // functions, then the recommended transformation will be bogus with
-// get_commit_tree() on the LHS.
+// repo_get_commit_tree() on the LHS.
 @@